@@ -132,10 +132,10 @@ static int s_startup_notify_screen = 0;
 #define MAX_SOCK_FILE (sizeof(struct sockaddr_un) - offsetof(struct sockaddr_un,sun_path))
 static char sock_file[MAX_SOCK_FILE];
 
+// Can't use QGuiApplication::platformName() here, there is no app instance.
 #if HAVE_X11 || HAVE_XCB
 static const char* displayEnvVarName_c()
 {
-    // Can't use QGuiApplication::platformName() here, there is no app instance.
     return "DISPLAY";
 }
 static inline QByteArray displayEnvVarName()
@@ -533,7 +533,7 @@ static pid_t launch(int argc, const char *_name, const char *args,
 #if HAVE_XCB
     KStartupInfoId startup_id;
     startup_id.initId(startup_id_str);
-    if (!startup_id.none()) {
+    if (!startup_id.isNull()) {
         init_startup_info(startup_id, name, envc, envs);
     }
 #endif
@@ -590,7 +590,7 @@ static pid_t launch(int argc, const char *_name, const char *args,
         }
 
 #if HAVE_X11
-        if (startup_id.none()) {
+        if (startup_id.isNull()) {
             KStartupInfo::resetStartupEnv();
         } else {
             startup_id.setupStartupEnv();
@@ -779,7 +779,7 @@ static pid_t launch(int argc, const char *_name, const char *args,
         close(d.fd[0]);
     }
 #if HAVE_XCB
-    if (!startup_id.none()) {
+    if (!startup_id.isNull()) {
         if (d.fork && d.result == 0) { // launched successfully
             complete_startup_info(startup_id, d.fork);
         } else { // failure, cancel ASN
